channelName property
The name of the platform channel used for communication with native code.
Implementation
final String channelName = "com.hyperpay.sdk/channel";
The name of the platform channel used for communication with native code.
final String channelName = "com.hyperpay.sdk/channel";