shopperResultUrl property
The URL used by the payment gateway to redirect the user back to the app after a payment.
Implementation
final String shopperResultUrl;
The URL used by the payment gateway to redirect the user back to the app after a payment.
final String shopperResultUrl;