PaymentConst class

Constants used as payment type identifiers and status codes when communicating with the native HyperPay SDK over the method channel.

Constructors

PaymentConst()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

applePay → const String
Payment type identifier for Apple Pay.
customUi → const String
Payment type identifier for the Custom UI card flow.
customUiSTC → const String
Payment type identifier for the Custom UI STC Pay flow.
error → const String
Native SDK result string indicating a failed transaction.
googlePay → const String
Payment type identifier for Google Pay.
methodCall → const String
The method channel method name used for all HyperPay SDK calls.
readyUi → const String
Payment type identifier for the HyperPay Ready UI flow.
samsungPay → const String
Payment type identifier for Samsung Pay.
storedCards → const String
Payment type identifier for paying with a stored/tokenised card.
success → const String
Native SDK result string indicating a successful transaction.
sync → const String
Native SDK result string indicating a synchronous (pending) transaction.