methodCall constant
String
const methodCall
The method channel method name used for all HyperPay SDK calls.
Implementation
static const String methodCall = "gethyperpayresponse";
The method channel method name used for all HyperPay SDK calls.
static const String methodCall = "gethyperpayresponse";