PaymentLang class

Language locale constants for the HyperPay payment UI.

Pass the appropriate value to FlutterHyperPay.lang based on the target platform and desired locale.

Constructors

PaymentLang()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

androidARLang → const String
Arabic locale for Android.
androidENLang → const String
English locale for Android.
iosARLang → const String
Arabic locale for iOS.
iosENLang → const String
English locale for iOS.