errorCode property
Machine-readable error code from the native SDK (e.g. "PLATFORM_NOT_SUPPORTED").
null when the transaction is not in an error state.
Implementation
final String? errorCode;
Machine-readable error code from the native SDK (e.g. "PLATFORM_NOT_SUPPORTED").
null when the transaction is not in an error state.
final String? errorCode;