CustomUISTC class
Class CustomUISTC is used to store the payment type, checkout ID, and phone number for custom UI payment.
Constructors
- CustomUISTC({required String checkoutId, required String phoneNumber})
- Creates a CustomUISTC payment request.
Properties
- checkoutId → String
-
The HyperPay checkout ID.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- paymentType → String
-
The payment type, defaults to PaymentConst.customUiSTC.
final
- phoneNumber → String
-
The shopper's phone number for STC Pay verification.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited