ReadyUI class

ReadyUI class holds all the necessary data related to the ReadyUI payment method which is used in PaymentConst. It is required to provide checkoutId when initializing the class. Also, we can provide brandName and themColorHexIOS as optional values. setStorePaymentDetailsMode is set to false by default.

Constructors

ReadyUI({required String checkoutId, required List<String> brandsName, String merchantIdApplePayIOS = "", String countryCodeApplePayIOS = "", String companyNameApplePayIOS = "", String themColorHexIOS = "", bool setStorePaymentDetailsMode = false, List<String> supportedNetworksApplePayIOS = const ["visa", "masterCard", "mada"]})
Creates a ReadyUI configuration.

Properties

brandsName List<String>
List of brands to be shown in the ReadyUI (e.g., "VISA", "MASTERCARD").
final
checkoutId String
The HyperPay checkout ID.
final
companyNameApplePayIOS String
Apple Pay Company Name (iOS only).
final
countryCodeApplePayIOS String
Apple Pay Country Code (iOS only).
final
hashCode int
The hash code for this object.
no setterinherited
merchantIdApplePayIOS String
Apple Pay Merchant ID (iOS only).
final
paymentType String
The payment type, defaults to PaymentConst.readyUi.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setStorePaymentDetailsMode bool
Whether to enable tokenization to store payment details.
final
supportedNetworksApplePayIOS List<String>
Supported networks for Apple Pay on iOS.
final
themColorHexIOS String
Hexadecimal color code for the iOS ReadyUI theme.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited