CustomUI class
This class is used to define a CustomUI object which is used to make payments using the PaymentConst. customUi payment type. It has parameters to define the checkoutId, brandName, cardNumber, holderName, month, year, cvv and enabledTokenization (optional).
Constructors
Properties
- brandName → String
-
The name of the brand (e.g., "VISA", "MASTERCARD").
final
- cardNumber → String
-
The credit or debit card number.
final
- checkoutId → String
-
The HyperPay checkout ID.
final
- cvv → String
-
The 3 or 4-digit CVV/CVC security code.
final
- enabledTokenization → bool
-
Whether to enable tokenization for this transaction.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- holderName → String
-
The name of the cardholder as it appears on the card.
final
- month → String
-
The expiration month of the card (e.g., "12").
final
- paymentType → String
-
The payment type, defaults to PaymentConst.customUi.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- year → String
-
The expiration year of the card (e.g., "2025").
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited