GooglePayUI class
Model class representing the parameters required to initiate a Google Pay payment.
Constructors
-
GooglePayUI({required String checkoutId, required String googlePayMerchantId, required String gatewayMerchantId, required String countryCode, required String currencyCode, required String amount, List<
String> allowedCardNetworks = const ["VISA", "MASTERCARD", "MADA"], List<String> allowedCardAuthMethods = const ["PAN_ONLY", "CRYPTOGRAM_3DS"]}) -
const
Properties
-
allowedCardAuthMethods
→ List<
String> -
Allowed card authentication methods. Defaults to PAN_ONLY and CRYPTOGRAM_3DS.
final
-
allowedCardNetworks
→ List<
String> -
Allowed card networks. Defaults to VISA, MASTERCARD, and MADA.
final
- amount → String
-
Transaction amount as a string (e.g. "10.00").
final
- checkoutId → String
-
The HyperPay checkout ID for this transaction.
final
- countryCode → String
-
Two-letter ISO 3166 country code (e.g. "SA").
final
- currencyCode → String
-
ISO 4217 currency code (e.g. "SAR").
final
- gatewayMerchantId → String
-
The HyperPay entity ID used as the gateway merchant ID.
final
- googlePayMerchantId → String
-
The Google Pay merchant ID from the Google Pay Business Console.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited