StoredCards class
This is the class for StoredCards. It has fields to store payment type, checkoutId, tokenId, brandName and cvv. PaymentType is set to the PaymentConst.readyUi, checkoutId and tokenId are required fields and brandName and cvv are optional fields.
Constructors
- StoredCards({required String checkoutId, required String tokenId, required String cvv, String? brandName})
- Creates a StoredCards payment request.
Properties
- brandName → String?
-
The brand name of the stored card (e.g., "VISA").
final
- checkoutId → String
-
The HyperPay checkout ID.
final
- cvv → String
-
The 3 or 4-digit CVV code for the stored card.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- paymentType → String
-
The payment type, defaults to PaymentConst.storedCards.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenId → String
-
The token ID representing a previously stored payment card.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited